<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * カスタマイザーの設定からクラス名を返す関数
 *
 * @param string
 * @return string|false クラス名
 * @version 1.0.0
 */
if( !function_exists( 'nmd_get_entries_class' ) ) {
    function nmd_get_entries_class($column = 'multi') {
        /**
         * 1カラムか2カラムかでレイアウトが異なる
         */
        $option_name = $column === 'multi' ? 'nmd_archive_layout_multi' : 'nmd_archive_layout_single';
        $default = $column === 'multi' ? 'sidebar-1column' : 'main-2columns';
        $entries_type = get_option($option_name, $default);
        $class = 'entry ';

        switch ($entries_type) {
            case 'sidebar-1column':
                $class .= 'sidebar-1column';
                break;

            case 'sidebar-1column-big':
                $class .= 'sidebar-1column-big';
                break;

            case 'sidebar-2columns':
                $class .= 'sidebar-2columns';
                break;

            case 'sidebar-2columns-big':
                $class .= 'sidebar-2columns-big';
                break;

            case 'sidebar-3columns':
                $class .= 'sidebar-3columns';
                break;

            case 'main-2columns':
                $class .= 'main-2columns';
                break;

            case 'main-2columns-big':
                $class .= 'main-2columns-big';
                break;

            case 'main-3columns':
                $class .= 'main-3columns';
                break;

            case 'main-4columns':
                $class .= 'main-4columns';
                break;
            
            default:
                $class .= 'sidebar-1column';
                break;
        }

        return $class;
    }
}

/**
 * カスタマイザー設定から記事一覧の設定を返す関数
 *
 * @param string
 * @return array クラス名
 * @version 1.0.0
 */
if( !function_exists( 'nmd_get_entries_settings' ) ) {
    function nmd_get_entries_settings($column = 'multi') {
        /**
         * 1カラムか2カラムかでレイアウトが異なる
         */
        $option_name = $column === 'multi' ? 'nmd_archive_layout_multi' : 'nmd_archive_layout_single';
        $default = $column === 'multi' ? 'sidebar-1column' : 'main-2columns';
        $entries_type = get_option($option_name, $default);
        $class = 'entry ';
        $str_num_pc = 56;
        $str_num_sp = 30;

        switch ($entries_type) {
            case 'sidebar-1column':
                $class .= 'sidebar-1column';
                $str_num_pc = 56;
                $str_num_sp = 30;
                break;

            case 'sidebar-1column-big':
                $class .= 'sidebar-1column-big';
                $str_num_pc = 83;
                $str_num_sp = 36;
                break;

            case 'sidebar-2columns':
                $class .= 'sidebar-2columns';
                $str_num_pc = 30;
                $str_num_sp = 30;
                break;

            case 'sidebar-2columns-big':
                $class .= 'sidebar-2columns-big';
                $str_num_pc = 53;
                $str_num_sp = 53;
                break;

            case 'sidebar-3columns':
                $class .= 'sidebar-3columns';
                $str_num_pc = 25;
                $str_num_sp = 27;
                break;

            case 'main-2columns':
                $class .= 'main-2columns';
                $str_num_pc = 56;
                $str_num_sp = 30;
                break;

            case 'main-2columns-big':
                $class .= 'main-2columns-big';
                $str_num_pc = 53;
                $str_num_sp = 48;
                break;

            case 'main-3columns':
                $class .= 'main-3columns';
                $str_num_pc = 53;
                $str_num_sp = 37;
                break;

            case 'main-4columns':
                $class .= 'main-4columns';
                $str_num_pc = 30;
                $str_num_sp = 35;
                break;
            
            default:
                $class .= 'sidebar-1column';
                break;
        }

        $setting = array(
            'class' => $class,
            'str_num_pc' => $str_num_pc,
            'str_num_sp' => $str_num_sp,
        );

        return $setting;
    }
}