<?php

/**
 * メニューの設定
 */
if (!defined('ABSPATH')) {
	exit;
}

if (!function_exists('nmd_setup_nav')) {
	function nmd_setup_nav()
	{
		register_nav_menus(array(
			'global'  	=> 'グローバルナビ（PC）',
			'sp-global'	=> 'グローバルナビ（スマホ）',
			'footer'	=> 'フッターナビ',
		));
	}
}
add_action('after_setup_theme', 'nmd_setup_nav');

function nmd_display_recentpost_navmenu($item_output, $item, $depth, $args)
{

	if (!isset($args->theme_location)) return $item_output;

	if ($args->theme_location !== 'global') return $item_output;

	/**
	 * 親メニューの場合
	 */
	if (($depth === 0)) {
		$display_recent_post = get_post_meta($item->ID, '_menu_item_recent_post', true);

		if ($display_recent_post !== 'this_cat') return $item_output;

		$args = array(
			'posts_per_page'   => 4,
			'tax_query' => array(
				array(
					'taxonomy' => $item->object,
					'field'    => 'id',
					'terms'    => $item->object_id,
				),
			),
		);

		$the_query = new WP_Query($args);

		ob_start();
?>
		<?php if ($the_query->have_posts()) : ?>
			<div class="sub-menu">
				<div class="menu-recent-post">
					<div class="menu-recent-post__inner">
						<?php while ($the_query->have_posts()) : $the_query->the_post(); ?>
							<?php
							$title		= get_the_title();
							$url		= get_the_permalink();
							$mb_title	= nmd_mb_substr_text($title, 21);
							$thumb_url	= nmd_get_thumbnail_url(get_the_ID(), 'medium_large');
							?>
							<a href="<?php echo $url; ?>" class="menu-recent-post__box">
								<div class="menu-recent-post__img">
									<img src="<?php echo $thumb_url; ?>" alt="<?php echo $mb_title; ?>">
								</div>
								<p><?php echo $mb_title; ?></p>
							</a>

						<?php endwhile; ?>
						<?php wp_reset_postdata(); ?>
					</div>
				</div>
			</div>

		<?php endif; ?>
		<?php
		$entries = ob_get_contents();
		ob_end_clean();

		$item_output = $item_output . $entries;
	}

	if (($depth === 1)) {
		$display_recent_post = get_post_meta($item->menu_item_parent, '_menu_item_recent_post', true);

		if ($display_recent_post !== 'child_cat') return $item_output;

		if ($item->type === 'taxonomy') {

			$item_output = str_replace('class="', 'class="menu-item-has-posts ', $item_output);

			$args = array(
				'posts_per_page'   => 4,
				'tax_query' => array(
					array(
						'taxonomy' => $item->object,
						'field'    => 'id',
						'terms'    => $item->object_id,
					),
				),
			);

			$the_query = new WP_Query($args);

			ob_start();
		?>
			<?php if ($the_query->have_posts()) : ?>
				<div class="menu-content-right">
					<div class="menu-content-right__inner">
						<?php while ($the_query->have_posts()) : $the_query->the_post(); ?>
							<?php
							$title		= get_the_title();
							$url		= get_the_permalink();
							$mb_title	= nmd_mb_substr_text($title, 21);
							$thumb_url	= nmd_get_thumbnail_url(get_the_ID(), 'medium_large');
							?>
							<a href="<?php echo $url; ?>" class="menu-content-right__box">
								<div class="menu-content-right__img">
									<img src="<?php echo $thumb_url; ?>" alt="<?php echo $mb_title; ?>">
								</div>
								<p><?php echo $mb_title; ?></p>
							</a>
						<?php endwhile; ?>
						<?php wp_reset_postdata(); ?>
					</div>
				</div>
			<?php endif; ?>
	<?php
			$entries = ob_get_contents();
			ob_end_clean();

			$item_output = $item_output . $entries;
		}
	}


	/* if (!empty($item->description)) {
        $item_output = str_replace('">' . $args->link_before . $item->title . $args->link_after, '"><span class="menu-item-description">' . $item->description . '</span><br />' . $args->link_before . $item->title . $args->link_after, $item_output);
    } */
	return $item_output;
}
add_filter('walker_nav_menu_start_el', 'nmd_display_recentpost_navmenu', 10, 4);


function nmd_add_class_nav_menu($classes, $item, $args, $depth)
{
	$display_recent_post = get_post_meta($item->ID, '_menu_item_recent_post', true);

	if ($depth !== 0) return $classes;

	switch ($display_recent_post) {
		case 'this_cat':
			$classes[] = "has-recent-post";
			break;

		case 'child_cat':
			$classes[] = "has-recent-post";
			break;

		default:
			// no action
			break;
	}

	if ($depth === 0) {
		$classes[] = "parent";
	}
	return $classes;
}
add_filter('nav_menu_css_class', 'nmd_add_class_nav_menu', 10, 4);

function nmd_add_field_menu_item($item_id, $menu_item, $depth, $args)
{
	$menu_type = $menu_item->object;
	$menu_item_recent_post = get_post_meta($item_id, '_menu_item_recent_post', true);
	?>
	<?php if ($depth === 0) : ?>
		<p class="field-display-post description">
			<?php wp_nonce_field('nmd_menu_meta_nonce', '_nmd_menu_meta_nonce_name'); ?>
			<?php _e('新着記事の表示', NMD_TEXT_DOMAIN); ?><br />
			<label>
				<input type="radio" value="none" name="menu-item-recent-post[<?php echo $item_id; ?>]" <?php if ($menu_item_recent_post === 'none' || empty($menu_item_recent_post)) echo 'checked'; ?> />
				<?php _e('表示なし', NMD_TEXT_DOMAIN); ?>
			</label><br />
			<?php if ($menu_type === 'category') : ?>
				<label>
					<input type="radio" value="this_cat" name="menu-item-recent-post[<?php echo $item_id; ?>]" <?php if ($menu_item_recent_post === 'this_cat') echo 'checked'; ?> />
					<?php _e('このカテゴリーの新着記事を表示（階層設定不可）', NMD_TEXT_DOMAIN); ?>
				</label><br />
			<?php endif; ?>
			<label>
				<input type="radio" value="child_cat" name="menu-item-recent-post[<?php echo $item_id; ?>]" <?php if ($menu_item_recent_post === 'child_cat') echo 'checked'; ?> />
				<?php _e('下層メニューがカテゴリーの場合、新着記事を表示', NMD_TEXT_DOMAIN); ?>
			</label><br />
		</p>
		<p>
			<span class="description"><?php _e('「下層メニューがカテゴリーの場合、新着記事を表示」を選択した場合、下層メニューをカテゴリーに設定してください。', NMD_TEXT_DOMAIN); ?></span>
		</p>
	<?php endif; ?>
<?php
}
add_action('wp_nav_menu_item_custom_fields', 'nmd_add_field_menu_item', 10, 4);

function nmd_nav_menu_update($menu_id, $menu_item_db_id)
{

	if (!isset($_POST['_nmd_menu_meta_nonce_name']) || !wp_verify_nonce($_POST['_nmd_menu_meta_nonce_name'], 'nmd_menu_meta_nonce')) {
		return $menu_id;
	}

	if (isset($_POST['menu-item-recent-post'][$menu_item_db_id])) {
		$sanitized_data = sanitize_text_field($_POST['menu-item-recent-post'][$menu_item_db_id]);
		update_post_meta($menu_item_db_id, '_menu_item_recent_post', $sanitized_data);
	} else {
		delete_post_meta($menu_item_db_id, '_menu_item_recent_post');
	}
}
add_action('wp_update_nav_menu_item', 'nmd_nav_menu_update', 10, 2);
